# pocpy (Phase Only Correlation in Python)

This repository contains implementations of phase only correlation and rotation invariant phase only correlation in python.

## Installing pocpy

```console
$ pip install pocpy
```
